@@ -1,25 +1,14 @@
-//
-// Copyright (C) 2015~2015 by CSSlayer
-// wengxt@gmail.com
-//
-// This library is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 2.1 of the
-// License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; see the file COPYING. If not,
-// see <http://www.gnu.org/licenses/>.
-//
+/*
+ * SPDX-FileCopyrightText: 2015-2015 CSSlayer <wengxt@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
+ */
 #ifndef _FCITX_CONFIG_INIPARSER_H_
 #define _FCITX_CONFIG_INIPARSER_H_
 
 #include <fcitx-config/rawconfig.h>
+#include <fcitx-utils/standardpath.h>
 #include "fcitxconfig_export.h"
 
 namespace fcitx {
@@ -34,6 +23,12 @@ FCITXCONFIG_EXPORT bool safeSaveAsIni(const Configuration &,
                                       const std::string &name);
 FCITXCONFIG_EXPORT bool safeSaveAsIni(const RawConfig &,
                                       const std::string &name);
+FCITXCONFIG_EXPORT bool safeSaveAsIni(const Configuration &,
+                                      StandardPath::Type type,
+                                      const std::string &name);
+FCITXCONFIG_EXPORT bool safeSaveAsIni(const RawConfig &,
+                                      StandardPath::Type type,
+                                      const std::string &name);
 } // namespace fcitx
 
 #endif // _FCITX_CONFIG_INIPARSER_H_
